==> eVenn_2.1.5.tar.gz: eVenn/R/man.evenn.R <==
man.evenn <-
function()
{
  write("        ,.-.,                                                                                    ", file="")
  write("      .`     `.                                                                                  ", file="")
  write("     /.-., ,.-.`            *       *                                 ****      **      *******  ", file="")
  write("   .`    .`.    `.     ***   *     *   ***    ****   ****    *     * *    *   *  *      *        ", file="")
  write("  / `.  /   `.  / `  *     *  *   *  *     * *    * *    *    *   *      *       *      ******   ", file="")
  write(" |    ',_____,'    | ******   *   *  ******  *    * *    *     * *      *        *            *  ", file="")
  write(" `.     `   /     /  *         * *   *       *    * *    *     * *    *          *            *  ", file="")
  write("   ',    '_'    ,'    *****     *     *****  *    * *    *      *    ****** * ******* * ******   ", file="")
  write("     `'-'` `'-'`                                                                                 ", file="")
  write("\n#####################", file="")
  write("# eVenn Quick Start #", file="")
  write("#####################", file="")
  write("- Prototype:\n\t(annot=FALSE, path_res=\"\", path_lists=\"\", res=\"\", ud=FALSE, prop=FALSE, noms=\"\", overlaps=FALSE, f=0, display=FALSE)", file="")
  write("- Text tabulated files must be placed alone in a folder.", file="")
  write("- Linux users must use the put the folder path in \"path_lists\".", file="")
  write("- Default option produce a classical Venn diagram:\n\tevenn()", file="")
  write("- Venn diagram with up/down details and annotations:\n\tevenn(annot=TRUE, ud=TRUE)", file="")
  write("- Venn diagram with custom short names of lists:\n\tevenn(noms=c(\"A\", \"B\", \"C\", \"D\"))", file="")
  write("- Just the overlaps table:\n\tevenn(overlaps=TRUE)\n", file="")
  write("####################", file="")
  write("# eVenn Quick Help #", file="")
  write("####################", file="")
  write("- annot [TRUE/FALSE]:\tIf the lists to be compared are files with identifiers (used for comparisons) and data (annotations or whatever).", file="")
  write("\t\t\tThe identifiers data (Gene name and extended name) must be the 2nd and 3rd columns.", file="")
  write("- path_res [path]:\tPath used to save the results. The working directory is used by default [getwd()].", file="")
  write("- path_lists [path]:\tPath used to find the lists to be compared. There is no default.", file="")
  write("\t\t\tThe files must be text tabulated.", file="")
  write("- res [matrix]:\t\tBinary matrix showing which identifier belong to which lists.", file="")
  write("\t\t\tColumns are compared lists, rows are identifiers.", file="")
  write("- ud [TRUE/FALSE]:\tIf the details of up and down regulated genes should be shown.", file="")
  write("\t\t\tThen the source files must comport a \"ratios\" column.", file="")
  write("- prop [TRUE/FALSE]:\tIf the surfaces of the disks should be proportional to the size of the lists.", file="")
  write("- overlaps [TRUE/FALSE]:\tCompute the overlaping proportions for each couple of lists in two ways (A in B and B in A).", file="")
  write("\t\t\tA heatmap is created if at least three lists are processed.", file="")
  write("- f [0:1]:\tProduces a filtered matrix with overlaps proportions greater than f. Default f=0 is set to no filter..", file="")
  write("- Tk [TRUE/FALSE]:\tUse the tcltk library to graphically choose the source folder (Source lists), only with Linux.", file="")
  write("- display [TRUE/FALSE]:\tDraw a title in ascii art.", file="")
}

==> eVenn_2.1.6.tar.gz: eVenn/R/man.evenn.R <==
man.evenn <-
function()
{
  write("        ,.-.,                                                                                    ", file="")
  write("      .`     `.                                                                                  ", file="")
  write("     /.-., ,.-.`            *       *                                 ****      **       *****   ", file="")
  write("   .`    .`.    `.     ***   *     *   ***    ****   ****    *     * *    *   *  *      *        ", file="")
  write("  / `.  /   `.  / `  *     *  *   *  *     * *    * *    *    *   *      *       *      ******   ", file="")
  write(" |    ',_____,'    | ******   *   *  ******  *    * *    *     * *      *        *      *     *  ", file="")
  write(" `.     `   /     /  *         * *   *       *    * *    *     * *    *          *      *     *  ", file="")
  write("   ',    '_'    ,'    *****     *     *****  *    * *    *      *    ****** * ******* *  *****   ", file="")
  write("     `'-'` `'-'`                                                                                 ", file="")
  write("\n#####################", file="")
  write("# eVenn Quick Start #", file="")
  write("#####################", file="")
  write("- Prototype:\n\t(annot=FALSE, matLists=\"\", path_res=\"\", path_lists=\"\", res=\"\", ud=FALSE, prop=FALSE, noms=\"\", overlaps=FALSE, f=0, display=FALSE, FilesOut=TRUE, CompName=\"\")", file="")
  write("- Text tabulated files must be placed alone in a folder.", file="")
  write("- Linux users must use the put the folder path in \"path_lists\".", file="")
  write("- Default option produce a classical Venn diagram:\n\tevenn()", file="")
  write("- Venn diagram with up/down details and annotations:\n\tevenn(annot=TRUE, ud=TRUE)", file="")
  write("- Venn diagram with custom short names of lists:\n\tevenn(noms=c(\"A\", \"B\", \"C\", \"D\"))", file="")
  write("- Just the overlaps table:\n\tevenn(overlaps=TRUE)\n", file="")
  write("####################", file="")
  write("# eVenn Quick Help #", file="")
  write("####################", file="")
  write("- annot [TRUE/FALSE]:\tIf the lists to be compared are files with identifiers (used for comparisons) and data (annotations or whatever).", file="")
  write("\t\t\tThe identifiers data (Gene name and extended name) must be the 2nd and 3rd columns.", file="")
  write("- matLists [List of matrix]:\tTo use eVenn on matrix. The \"noms\" variable must be used to give names to the compared matrix / lists.", file="")
  write("- path_res [path]:\tPath used to save the results. The working directory is used by default [getwd()].", file="")
  write("- path_lists [path]:\tPath used to find the lists to be compared. There is no default.", file="")
  write("\t\t\tThe files must be text tabulated.", file="")
  write("- res [matrix]:\t\tBinary matrix showing which identifier belong to which lists.", file="")
  write("\t\t\tColumns are compared lists, rows are identifiers.", file="")
  write("- ud [TRUE/FALSE]:\tIf the details of up and down regulated genes should be shown.", file="")
  write("\t\t\tThen the source files must comport a \"ratios\" column.", file="")
  write("- prop [TRUE/FALSE]:\tIf the surfaces of the disks should be proportional to the size of the lists.", file="")
  write("- overlaps [TRUE/FALSE]:\tCompute the overlaping proportions for each couple of lists in two ways (A in B and B in A).", file="")
  write("\t\t\tA heatmap is created if at least three lists are processed.", file="")
  write("- f [0:1]:\tProduces a filtered matrix with overlaps proportions greater than f. Default f=0 is set to no filter..", file="")
  write("- Tk [TRUE/FALSE]:\tUse the tcltk library to graphically choose the source folder (Source lists), only with Linux.", file="")
  write("- display [TRUE/FALSE]:\tDraw a title in ascii art.", file="")
  write("- FilesOut [TRUE/FALSE]:\tFor use of eVenn without producing files but only return a results binary matrix. (results = evenn())t.", file="")
  write("- CompName [char]:\tName of the folder results.", file="")
}
